==> dasu_1.0.jar: edu/northwestern/dasu/ui/HVPlot.java <==
package edu.northwestern.dasu.ui;

import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.TreeMap;

import edu.northwestern.dasu.util.Pair;

public class HVPlot {
	public static final int LINE_GRAPH=1;
	public static final int SCATTER_GRAPH=2;
	private ArrayList<Pair<Long, Float>> points;
	
	private boolean showHighlight;
	private long x1Highlight;
	private long x2Highlight;
	
	private String plotTitle;
	private String xLabel;
	private String yLabel;
	
	private int graphType;
	
	public HVPlot(){
	}
	
	public HVPlot(ArrayList<Pair<Long,Float>> dataValues,String plotTitle, String xlabel, String ylabel){
		this.points = dataValues;
		this.plotTitle = plotTitle;
		this.xLabel = xlabel;
		this.yLabel = ylabel;
		graphType = LINE_GRAPH; // default is line
		showHighlight = false;
	}
	
	public void HighlightSection(long x1, long x2){
		showHighlight = true;
		x1Highlight = x1;
		x2Highlight = x2;
	}
	public ArrayList<Pair<Long, Float>> getPoints() {
		return points;
	}
	public void setPoints(ArrayList<Pair<Long, Float>> points) {
		this.points = points;
	}
	public void setTitle(String title){
		this.plotTitle = title;
	}
	public void setXLabel(String xlabel){
		this.xLabel = xlabel;
	}
	public void setYLabel(String ylabel){
		this.yLabel = ylabel;
	}
	public void setType(int type){
		graphType=type;
	}
	public String getTitle(){
		return plotTitle;
	}
	public String getXLabel(){
		return xLabel;
	}
	public String getyLabel(){
		return yLabel;
	}
	public int getType(){
		return graphType;
	}

	public boolean isShowHighlight() {
		return showHighlight;
	}

	public void setShowHighlight(boolean showHighlight) {
		this.showHighlight = showHighlight;
	}

	public long getX1Highlight() {
		return x1Highlight;
	}

	public void setX1Highlight(int x1Highlight) {
		this.x1Highlight = x1Highlight;
	}

	public long getX2Highlight() {
		return x2Highlight;
	}

	public void setX2Highlight(int x2Highlight) {
		this.x2Highlight = x2Highlight;
	}

	public String getPlotTitle() {
		return plotTitle;
	}

	public void setPlotTitle(String plotTitle) {
		this.plotTitle = plotTitle;
	}

	public String getxLabel() {
		return xLabel;
	}

	public void setxLabel(String xLabel) {
		this.xLabel = xLabel;
	}

	public int getGraphType() {
		return graphType;
	}

	public void setGraphType(int graphType) {
		this.graphType = graphType;
	}

	public static int getLineGraph() {
		return LINE_GRAPH;
	}

	public static int getScatterGraph() {
		return SCATTER_GRAPH;
	}

	public void setyLabel(String yLabel) {
		this.yLabel = yLabel;
	}
	
}

==> dasu_2.02.jar: edu/northwestern/dasu/ui/HVPlot.java <==
package edu.northwestern.dasu.ui;

import java.io.Serializable;
import java.util.ArrayList;

import edu.northwestern.dasu.util.Pair;

public class HVPlot implements Serializable {
	
	public static final int LINE_GRAPH=1;
	public static final int SCATTER_GRAPH=2;
	public static final int FORMAT_TIME=1;
	public static final int FORMAT_DATE=2;
	public static final int FORMAT_DAY_WEEK=3;
	public static final int FORMAT_MONTH=4;
	public static final int FORMAT_NUMBER=5;
	
	private ArrayList<Pair<Long, Float>> points;
	
	private boolean showHighlight;
	private long x1Highlight;
	private long x2Highlight;
	
	private String plotTitle = "emtpy";
	private String xLabel = "";
	private String yLabel = "";
	private int xLabelFormat = FORMAT_TIME; //default is time;
	
	private int graphType = LINE_GRAPH; // default is line
	
	public HVPlot(){
	}
	
	public HVPlot(ArrayList<Pair<Long,Float>> dataValues,String plotTitle, String xlabel, 
			String ylabel, int plotType, int xLabelFormat){
		
		this.points = dataValues;
		
		if (plotTitle != null)
			this.plotTitle = plotTitle;
		
		if (xlabel != null)
			this.xLabel = xlabel;
		
		if (ylabel != null)
			this.yLabel = ylabel;
		
		showHighlight = false;
		
		setGraphType(plotType);
		setXLabelFormat(xLabelFormat);
		
	}
	
	public void setXLabelFormat(int format) {
		
		if (format >= 1 && format <= 5)
			xLabelFormat = format; 
	}
	
	public int getXLabelFormat() {
		return xLabelFormat;
	}
	
	public void HighlightSection(long x1, long x2){
		showHighlight = true;
		x1Highlight = x1;
		x2Highlight = x2;
	}
	public ArrayList<Pair<Long, Float>> getPoints() {
		return points;
	}
	public void setPoints(ArrayList<Pair<Long, Float>> points) {
		this.points = points;
	}
	public void setTitle(String title){
		this.plotTitle = title;
	}
	public void setXLabel(String xlabel){
		this.xLabel = xlabel;
	}
	public void setYLabel(String ylabel){
		this.yLabel = ylabel;
	}
	public void setType(int type){
		graphType=type;
	}
	public String getTitle(){
		return plotTitle;
	}
	public String getXLabel(){
		return xLabel;
	}
	public String getyLabel(){
		return yLabel;
	}
	public int getType(){
		return graphType;
	}

	public boolean isShowHighlight() {
		return showHighlight;
	}

	public void setShowHighlight(boolean showHighlight) {
		this.showHighlight = showHighlight;
	}

	public long getX1Highlight() {
		return x1Highlight;
	}

	public void setX1Highlight(int x1Highlight) {
		this.x1Highlight = x1Highlight;
	}

	public long getX2Highlight() {
		return x2Highlight;
	}

	public void setX2Highlight(int x2Highlight) {
		this.x2Highlight = x2Highlight;
	}

	public String getPlotTitle() {
		return plotTitle;
	}

	public void setPlotTitle(String plotTitle) {
		this.plotTitle = plotTitle;
	}

	public String getxLabel() {
		return xLabel;
	}

	public void setxLabel(String xLabel) {
		this.xLabel = xLabel;
	}

	public int getGraphType() {
		return graphType;
	}

	public void setGraphType(int graphType) {
		
		if (graphType >=1 && graphType <=2)
			this.graphType = graphType;
	}

	public static int getLineGraph() {
		return LINE_GRAPH;
	}

	public static int getScatterGraph() {
		return SCATTER_GRAPH;
	}

	public void setyLabel(String yLabel) {
		this.yLabel = yLabel;
	}
	
}
